@@ -2,11 +2,11 @@
 #'
 #' This function constructs the amplitude boxplot
 #'
-#' @param gam matrix (\eqn{N} x \eqn{M}) of \eqn{M} warping functions with \eqn{N} samples
+#' @param warp_median fdawarp object from \link{time_warping} of aligned data using the median
 #' @param alpha quantile value (default=.05, i.e., 95\%)
 #' @param kp scalar for outlier cutoff (default=1)
 #' @param showplot shows plots of functions (default = T)
-#' @return Returns a list containing \item{median_x}{median warping function}
+#' @return Returns a phbox object containing \item{median_x}{median warping function}
 #' \item{Q1}{First quartile}
 #' \item{Q3}{Second quartile}
 #' \item{Q1a}{First quantile based on alpha}
@@ -20,8 +20,17 @@
 #' @export
 #' @examples
 #' data("simu_warp_median")
-#' out <- PhaseBoxplot(simu_warp_median$gam)
-PhaseBoxplot <- function(gam, alpha=.05, kp=1, showplot=T){
+#' out <- PhaseBoxplot(simu_warp_median, showplot=FALSE)
+PhaseBoxplot <- function(warp_median, alpha=.05, kp=1, showplot=TRUE){
+  gam <- warp_median$gam
+  if (warp_median$method != 'median'){
+      stop('need aligned to median, please rerun time_warping with method="median"')
+  }
+
+  if (warp_median$rsamps){
+    gam <- warp_median$gams
+  }
+
   M <- nrow(gam)
   N <- ncol(gam)
   lambda <- 0.5
@@ -40,7 +49,7 @@ PhaseBoxplot <- function(gam, alpha=.05, kp=1, showplot=T){
   for (i in 1:N){
     psi[,i] <- sqrt(gradient(gam[,i],binsize))
     v[,i] <- inv_exp_map(psi_median, psi[,i])
-    dx[i] = sqrt(trapz(time, v[,i]^2))
+    dx[i] <- sqrt(trapz(time, v[,i]^2))
   }
   dx_ordering <- sort(dx, index.return = T)$ix
   CR_50 <- dx_ordering[1:round(N/2)]  # 50% central region
@@ -141,67 +150,22 @@ PhaseBoxplot <- function(gam, alpha=.05, kp=1, showplot=T){
   minn <- gam[,min_index]
   maxx <- gam[,max_index]
 
+  out <- list(median_x=median_x,Q1=Q1,Q3=Q3,Q1a=Q1a,Q3a=Q3a,minn=minn,maxx=maxx,
+              outlier_index=outlier_index)
+  out$time <- time
+  out$psi_median <- psi_median
+  out$Q1_psi <- Q1_psi
+  out$Q1a_psi <- Q1a_psi
+  out$Q3_psi <- Q3_psi
+  out$Q3a_psi <- Q3a_psi
+  out$max_psi <- max_psi
+  out$min_psi <- min_psi
+  class(out) <- 'phbox'
+
   if (showplot){
-    plot(time, median_x, col="black",xlab="Time",main="Phase Boxplot", type="l", ylim=c(0, 1))
-    lines(time, Q1, col="blue")
-    lines(time, Q3, col="blue")
-    lines(time, Q1a, col="green")
-    lines(time, Q3a, col="green")
-    lines(time, maxx, col="red")
-    lines(time, minn, col="red")
-
-    s <- seq(0,1,length.out=100)
-    Fs2 <- matrix(0,length(time), 595)
-    Fs2[,1] <- (1-s[1]) * (minn-time) + s[1] * (Q1-time)
-    for (j in 2:100){
-      Fs2[,j] <- (1-s[j]) * (minn-time) + s[j] * (Q1a-time)
-      Fs2[,99+j] <- (1-s[j]) * (Q1a-time) + s[j] * (Q1-time)
-      Fs2[,198+j] <- (1-s[j]) * (Q1-time) + s[j] * (median_x-time)
-      Fs2[,297+j] <- (1-s[j]) * (median_x-time) + s[j] * (Q3-time)
-      Fs2[,396+j] <- (1-s[j]) * (Q3-time) + s[j] * (Q3a-time)
-      Fs2[,495+j] <- (1-s[j]) * (Q3a-time) + s[j] * (maxx-time)
-    }
-    d1<-sqrt(trapz(time,(psi_median-Q1_psi)^2))
-    d1a<-sqrt(trapz(time,(Q1_psi-Q1a_psi)^2))
-    dl<-sqrt(trapz(time,(Q1a_psi-min_psi)^2))
-    d3<-sqrt(trapz(time,(psi_median-Q3_psi)^2))
-    d3a<-sqrt(trapz(time,(Q3_psi-Q3a_psi)^2))
-    du<-sqrt(trapz(time,(Q3a_psi-max_psi)^2))
-    part1<-seq(-d1-d1a-dl,-d1-d1a,length.out=100)
-    part2<-seq(-d1-d1a,-d1,length.out=100)
-    part3<-seq(-d1,0,length.out=100)
-    part4<-seq(0,d3,length.out=100)
-    part5<-seq(d3,d3+d3a,length.out=100)
-    part6<-seq(d3+d3a,d3+d3a+du,length.out=100)
-    allparts<-c(part1,part2[2:100],part3[2:100],part4[2:100],part5[2:100],part6[2:100])
-
-    if (requireNamespace("plot3Drgl", quietly = TRUE)) {
-      p=plot3D::persp3D(x=time,y=allparts,z=Fs2,col=viridis(128),plot=F,main="Phase Surface Plot",ticktype="detailed",box=F)+
-        plot3D::lines3D(x=time,y=rep(0,M),z=(median_x-time),col="black",lwd=6,add=T,plot=F)+
-        plot3D::lines3D(x=time,y=rep(-d1,M),z=(Q1-time),col="blue",lwd=6,add=T,plot=F)+
-        plot3D::lines3D(x=time,y=rep(-d1-d1a,M),z=(Q1a-time),col="green",lwd=6,add=T,plot=F)+
-        plot3D::lines3D(x=time,y=rep(-d1-d1a-dl, M),z=(minn-time),col="red",lwd=6,add=T,plot=F)+
-        plot3D::lines3D(x=time,y=rep(d3, M),z=(Q3-time),col="blue",lwd=6,add=T,plot=F)+
-        plot3D::lines3D(x=time,y=rep(d3+d3a, M),z=(Q3a-time),col="green",lwd=6,add=T,plot=F)+
-        plot3D::lines3D(x=time,y=rep(d3+d3a+du, M),z=(maxx-time),col="red",lwd=6,add=T,plot=F)
-      plot3Drgl::plotrgl()
-      rgl::par3d("windowRect"= c(0,0,640,640))
-      rgl::grid3d(c("x", "y+", "z"))
-      rgl::axes3d(c('x--',"y--",'z'))
-      rgl::title3d(xlab="Time",ylab="Distance")
-    } else {
-      image(time, allparts, Fs2, main="Surface Plot", ylab="", col=viridis(128))
-      lines(time, rep(0, M), col="black", lwd=1)
-      lines(time, rep(-d1, M), col="blue", lwd=1)
-      lines(time, rep(-d1-d1a, M), col="green", lwd=1)
-      lines(time, rep(-d1-d1a-dl, M), col="red", lwd=1)
-      lines(time, rep(d3, M), col="blue", lwd=1)
-      lines(time, rep(d3+d3a, M), col="green", lwd=1)
-      lines(time, rep(d3+d3a+du, M), col="red", lwd=1)
-    }
+    plot(out)
 
   }
 
-  return(list(median_x=median_x,Q1=Q1,Q3=Q3,Q1a=Q1a,Q3a=Q3a,minn=minn,maxx=maxx,
-              outlier_index=outlier_index))
+  return(out)
 }
